# Generated by Django 1.11.28 on 2020-03-06 00:49

from bitfield.types import BitHandler
from django.db import migrations

from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def cleanup_audit_log_data(apps, schema_editor):
    """
    Fix `AuditLogEntry` rows that have pickled `Team` models in their `data` field. Also
    fixes some rows where flags were serialized as a BitHandler rather than a int.
    See sentry.api.serializers.models.auditlogentry::fix for details.
    """
    AuditLogEntry = apps.get_model("sentry", "AuditLogEntry")
    for audit_log in RangeQuerySetWrapperWithProgressBar(AuditLogEntry.objects.all()):
        modified = False
        if "flags" in audit_log.data and isinstance(audit_log.data["flags"], BitHandler):
            audit_log.data["flags"] = int(audit_log.data["flags"])
            modified = True
        if audit_log.event == 3:  # MEMBER_ACCEPT
            teams = audit_log.data.get("teams")
            if teams and hasattr(teams[0], "id"):
                # We have a team in here rather than just the expected data
                audit_log.data["teams"] = [team.id for team in teams]
                audit_log.data["teams_slugs"] = [team.slug for team in teams]
                modified = True
        if modified:
            audit_log.save()


class Migration(migrations.Migration):
    # This flag is used to mark that a migration shouldn't be automatically run in
    # production. We set this to True for operations that we think are risky and want
    # someone from ops to run manually and monitor.
    # General advice is that if in doubt, mark your migration as `is_dangerous`.
    # Some things you should always mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that
    #   they can be monitored. Since data migrations will now hold a transaction open
    #   this is even more important.
    # - Adding columns to highly active tables, even ones that are NULL.
    is_dangerous = True

    # This flag is used to decide whether to run this migration in a transaction or not.
    # By default we prefer to run in a transaction, but for migrations where you want
    # to `CREATE INDEX CONCURRENTLY` this needs to be set to False. Typically you'll
    # want to create an index concurrently when adding one to an existing table.
    atomic = False

    dependencies = [("sentry", "0050_auto_20200306_2346")]

    operations = [
        migrations.RunPython(code=cleanup_audit_log_data, reverse_code=migrations.RunPython.noop)
    ]
