import { __extends, __makeTemplateObject } from "tslib";
import React from 'react';
import { css } from '@emotion/core';
import styled from '@emotion/styled';
import memoize from 'lodash/memoize';
import moment from 'moment';
import Access from 'app/components/acl/access';
import ActorAvatar from 'app/components/avatar/actorAvatar';
import Button from 'app/components/button';
import ButtonBar from 'app/components/buttonBar';
import Confirm from 'app/components/confirm';
import ErrorBoundary from 'app/components/errorBoundary';
import IdBadge from 'app/components/idBadge';
import Link from 'app/components/links/link';
import TimeSince from 'app/components/timeSince';
import { IconArrow, IconDelete, IconSettings, IconUser } from 'app/icons';
import { t, tct } from 'app/locale';
import overflowEllipsis from 'app/styles/overflowEllipsis';
import space from 'app/styles/space';
import { AlertRuleThresholdType } from 'app/views/settings/incidentRules/types';
import AlertBadge from '../alertBadge';
import { IncidentStatus } from '../types';
import { isIssueAlert } from '../utils';
var RuleListRow = /** @class */ (function (_super) {
    __extends(RuleListRow, _super);
    function RuleListRow() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * Memoized function to find a project from a list of projects
         */
        _this.getProject = memoize(function (slug, projects) {
            return projects.find(function (project) { return project.slug === slug; });
        });
        return _this;
    }
    RuleListRow.prototype.activeIncident = function () {
        var _a;
        var rule = this.props.rule;
        return (((_a = rule.latestIncident) === null || _a === void 0 ? void 0 : _a.status) !== undefined &&
            [IncidentStatus.CRITICAL, IncidentStatus.WARNING].includes(rule.latestIncident.status));
    };
    RuleListRow.prototype.renderLastIncidentDate = function () {
        var rule = this.props.rule;
        if (isIssueAlert(rule)) {
            return null;
        }
        if (!rule.latestIncident) {
            return t('Never triggered');
        }
        if (this.activeIncident()) {
            return (<div>
          {t('Triggered ')}
          <TimeSince date={rule.latestIncident.dateCreated}/>
        </div>);
        }
        return (<div>
        {t('Resolved ')}
        <TimeSince date={rule.latestIncident.dateClosed}/>
      </div>);
    };
    RuleListRow.prototype.renderAlertRuleStatus = function () {
        var _a;
        var rule = this.props.rule;
        if (isIssueAlert(rule)) {
            return null;
        }
        var activeIncident = this.activeIncident();
        var criticalTrigger = rule === null || rule === void 0 ? void 0 : rule.triggers.find(function (_a) {
            var label = _a.label;
            return label === 'critical';
        });
        var warningTrigger = rule === null || rule === void 0 ? void 0 : rule.triggers.find(function (_a) {
            var label = _a.label;
            return label === 'warning';
        });
        var trigger = activeIncident && ((_a = rule.latestIncident) === null || _a === void 0 ? void 0 : _a.status) === IncidentStatus.CRITICAL
            ? criticalTrigger
            : warningTrigger !== null && warningTrigger !== void 0 ? warningTrigger : criticalTrigger;
        var iconColor = 'green300';
        if (activeIncident) {
            iconColor =
                (trigger === null || trigger === void 0 ? void 0 : trigger.label) === 'critical'
                    ? 'red300'
                    : (trigger === null || trigger === void 0 ? void 0 : trigger.label) === 'warning'
                        ? 'yellow300'
                        : 'green300';
        }
        var thresholdTypeText = activeIncident && rule.thresholdType === AlertRuleThresholdType.ABOVE
            ? t('Above')
            : t('Below');
        return (<FlexCenter>
        <IconArrow color={iconColor} direction={activeIncident && rule.thresholdType === AlertRuleThresholdType.ABOVE
                ? 'up'
                : 'down'}/>
        <TriggerText>{thresholdTypeText + " " + (trigger === null || trigger === void 0 ? void 0 : trigger.alertThreshold)}</TriggerText>
      </FlexCenter>);
    };
    RuleListRow.prototype.render = function () {
        var _a, _b, _c, _d;
        var _e = this.props, rule = _e.rule, projectsLoaded = _e.projectsLoaded, projects = _e.projects, organization = _e.organization, orgId = _e.orgId, onDelete = _e.onDelete, userTeams = _e.userTeams;
        var dateCreated = moment(rule.dateCreated).format('ll');
        var slug = rule.projects[0];
        var editLink = "/organizations/" + orgId + "/alerts/" + (isIssueAlert(rule) ? 'rules' : 'metric-rules') + "/" + slug + "/" + rule.id + "/";
        var hasRedesign = !isIssueAlert(rule) && organization.features.includes('alert-details-redesign');
        var detailsLink = "/organizations/" + orgId + "/alerts/rules/details/" + rule.id + "/";
        var ownerId = (_a = rule.owner) === null || _a === void 0 ? void 0 : _a.split(':')[1];
        var teamActor = ownerId
            ? { type: 'team', id: ownerId, name: '' }
            : null;
        var canEdit = ownerId ? userTeams.has(ownerId) : true;
        var hasAlertOwnership = organization.features.includes('team-alerts-ownership');
        var hasAlertList = organization.features.includes('alert-list');
        var alertLink = <Link to={hasRedesign ? detailsLink : editLink}>{rule.name}</Link>;
        return (<ErrorBoundary>
        {!hasAlertList ? (<React.Fragment>
            <RuleType>{isIssueAlert(rule) ? t('Issue') : t('Metric')}</RuleType>
            <Title>{alertLink}</Title>
          </React.Fragment>) : (<React.Fragment>
            <AlertNameWrapper isIncident={isIssueAlert(rule)}>
              <FlexCenter>
                <AlertBadge status={(_b = rule === null || rule === void 0 ? void 0 : rule.latestIncident) === null || _b === void 0 ? void 0 : _b.status} isIssue={isIssueAlert(rule)} hideText/>
              </FlexCenter>
              <AlertNameAndStatus>
                <div>{alertLink}</div>
                {!isIssueAlert(rule) && this.renderLastIncidentDate()}
              </AlertNameAndStatus>
            </AlertNameWrapper>
            <FlexCenter>{this.renderAlertRuleStatus()}</FlexCenter>
          </React.Fragment>)}

        <ProjectBadge avatarSize={18} project={!projectsLoaded ? { slug: slug } : this.getProject(slug, projects)}/>
        {hasAlertOwnership && (<FlexCenter>
            {teamActor ? (<ActorAvatar actor={teamActor} size={24}/>) : (<IconUser size="20px" color="gray400"/>)}
          </FlexCenter>)}
        {!hasAlertList && <CreatedBy>{(_d = (_c = rule === null || rule === void 0 ? void 0 : rule.createdBy) === null || _c === void 0 ? void 0 : _c.name) !== null && _d !== void 0 ? _d : '-'}</CreatedBy>}
        <FlexCenter>{dateCreated}</FlexCenter>
        <RightColumn>
          <Access access={['alerts:write']}>
            {function (_a) {
                var hasAccess = _a.hasAccess;
                return (<ButtonBar gap={1}>
                <Confirm disabled={!hasAccess || !canEdit} message={tct("Are you sure you want to delete [name]? You won't be able to view the history of this alert once it's deleted.", {
                        name: rule.name,
                    })} header={t('Delete Alert Rule?')} priority="danger" confirmText={t('Delete Rule')} onConfirm={function () { return onDelete(slug, rule); }}>
                  <Button type="button" icon={<IconDelete />} size="small" title={t('Delete')}/>
                </Confirm>
                <Button size="small" type="button" icon={<IconSettings />} title={t('Edit')} href={editLink}/>
              </ButtonBar>);
            }}
          </Access>
        </RightColumn>
      </ErrorBoundary>);
    };
    return RuleListRow;
}(React.Component));
var columnCss = css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  height: 100%;\n"], ["\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  height: 100%;\n"])));
var RightColumn = styled('div')(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  display: flex;\n  justify-content: flex-start;\n  align-items: center;\n  padding: ", " ", ";\n"], ["\n  display: flex;\n  justify-content: flex-start;\n  align-items: center;\n  padding: ", " ", ";\n"])), space(1.5), space(2));
var RuleType = styled('div')(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  font-size: ", ";\n  font-weight: 400;\n  color: ", ";\n  text-transform: uppercase;\n  ", "\n"], ["\n  font-size: ", ";\n  font-weight: 400;\n  color: ", ";\n  text-transform: uppercase;\n  ", "\n"])), function (p) { return p.theme.fontSizeSmall; }, function (p) { return p.theme.gray300; }, columnCss);
var Title = styled('div')(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  ", "\n  ", "\n"], ["\n  ", "\n  ", "\n"])), overflowEllipsis, columnCss);
var CreatedBy = styled('div')(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  ", "\n  ", "\n"], ["\n  ", "\n  ", "\n"])), overflowEllipsis, columnCss);
var FlexCenter = styled('div')(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n"], ["\n  display: flex;\n  align-items: center;\n"])));
var AlertNameWrapper = styled(FlexCenter)(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  ", "\n"], ["\n  ", "\n"])), function (p) { return p.isIncident && "padding: " + space(3) + " " + space(2) + "; line-height: 2.4;"; });
var AlertNameAndStatus = styled('div')(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n  margin-left: ", ";\n"], ["\n  margin-left: ", ";\n"])), space(1.5));
var ProjectBadge = styled(IdBadge)(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n  flex-shrink: 0;\n"], ["\n  flex-shrink: 0;\n"])));
var TriggerText = styled('div')(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n  margin-left: ", ";\n  white-space: nowrap;\n"], ["\n  margin-left: ", ";\n  white-space: nowrap;\n"])), space(1));
export default RuleListRow;
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9, templateObject_10;
//# sourceMappingURL=row.jsx.map