import React, { useEffect } from 'react';
import { useSortable } from '@dnd-kit/sortable';
import theme from 'app/utils/theme';
import WidgetCard from './widgetCard';
import WidgetWrapper from './widgetWrapper';
var initialStyles = {
    x: 0,
    y: 0,
    scaleX: 1,
    scaleY: 1,
    zIndex: 'auto',
};
function SortableWidget(props) {
    var widget = props.widget, dragId = props.dragId, isEditing = props.isEditing, onDelete = props.onDelete, onEdit = props.onEdit;
    var _a = useSortable({
        id: dragId,
        transition: null,
    }), attributes = _a.attributes, listeners = _a.listeners, setNodeRef = _a.setNodeRef, transform = _a.transform, currentWidgetDragging = _a.isDragging, isSorting = _a.isSorting;
    useEffect(function () {
        if (!currentWidgetDragging) {
            return undefined;
        }
        document.body.style.cursor = 'grabbing';
        return function cleanup() {
            document.body.style.cursor = '';
        };
    }, [currentWidgetDragging]);
    return (<WidgetWrapper ref={setNodeRef} displayType={widget.displayType} layoutId={dragId} style={{
            // Origin is set to top right-hand corner where the drag handle is placed.
            // Otherwise, set the origin to be the top left-hand corner when swapping widgets.
            originX: currentWidgetDragging ? 1 : 0,
            originY: 0,
            boxShadow: currentWidgetDragging ? theme.dropShadowHeavy : 'none',
            borderRadius: currentWidgetDragging ? theme.borderRadius : undefined,
        }} animate={transform
            ? {
                x: transform.x,
                y: transform.y,
                scaleX: (transform === null || transform === void 0 ? void 0 : transform.scaleX) && transform.scaleX <= 1 ? transform.scaleX : 1,
                scaleY: (transform === null || transform === void 0 ? void 0 : transform.scaleY) && transform.scaleY <= 1 ? transform.scaleY : 1,
                zIndex: currentWidgetDragging ? theme.zIndex.modal : 'auto',
            }
            : initialStyles} transition={{
            duration: !currentWidgetDragging ? 0.25 : 0,
            easings: {
                type: 'spring',
            },
        }}>
      <WidgetCard widget={widget} isEditing={isEditing} onDelete={onDelete} onEdit={onEdit} isSorting={isSorting} hideToolbar={isSorting} currentWidgetDragging={currentWidgetDragging} draggableProps={{
            attributes: attributes,
            listeners: listeners,
        }} showContextMenu/>
    </WidgetWrapper>);
}
export default SortableWidget;
//# sourceMappingURL=sortableWidget.jsx.map